@@ -148,10 +148,7 @@ effsize <- function(data, ..., type = c("phi", "cramer", "tschuprow", "cont", "w
   # Initial Check --------------------------------------------------------------
 
   # Check if input 'data' is missing
-  if (isTRUE(missing(data))) { stop("Please specify a a vector, factor or data frame for the argument 'data'", call. = FALSE) }
-
-  # Check if input 'data' is NULL
-  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
+  if (isTRUE(missing(data) || is.null(data))) { stop("Please specify a a vector, factor or data frame for the argument 'data'", call. = FALSE) }
 
   #_____________________________________________________________________________
   #
